@@ -39,10 +39,10 @@ namespace Kwave
 	AsciiDecoder();
 
 	/** Destructor */
-	virtual ~AsciiDecoder();
+        virtual ~AsciiDecoder() Q_DECL_OVERRIDE;
 
 	/** Returns a new instance of the decoder */
-	Kwave::Decoder *instance() Q_DECL_OVERRIDE;
+        virtual Kwave::Decoder *instance() Q_DECL_OVERRIDE;
 
 	/**
 	 * Opens the source and decodes the header information.
@@ -51,7 +51,7 @@ namespace Kwave
 	 * @param source file or other source with a stream of bytes
 	 * @return true if succeeded, false on errors
 	 */
-	bool open(QWidget *widget, QIODevice &source) Q_DECL_OVERRIDE;
+        virtual bool open(QWidget *widget, QIODevice &source) Q_DECL_OVERRIDE;
 
 	/**
 	 * Decodes a stream of bytes into a MultiWriter
@@ -60,12 +60,13 @@ namespace Kwave
 	 * @param dst MultiWriter that receives the audio data
 	 * @return true if succeeded, false on errors
 	 */
-	bool decode(QWidget *widget, Kwave::MultiWriter &dst) Q_DECL_OVERRIDE;
+        virtual bool decode(QWidget *widget, Kwave::MultiWriter &dst)
+            Q_DECL_OVERRIDE;
 
 	/**
 	 * Closes the source.
 	 */
-	void close() Q_DECL_OVERRIDE;
+        virtual void close() Q_DECL_OVERRIDE;
 
     private:
 
