@@ -39,10 +39,10 @@ namespace Kwave
 	AsciiEncoder();
 
 	/** Destructor */
-	virtual ~AsciiEncoder();
+        virtual ~AsciiEncoder() Q_DECL_OVERRIDE;
 
 	/** Returns a new instance of the encoder */
-	Kwave::Encoder *instance() Q_DECL_OVERRIDE;
+        virtual Kwave::Encoder *instance() Q_DECL_OVERRIDE;
 
 	/**
 	 * Encodes a signal into a stream of bytes.
@@ -53,12 +53,14 @@ namespace Kwave
 	 * @param meta_data meta information about the file to be saved
 	 * @return true if succeeded, false on errors
 	 */
-	bool encode(QWidget *widget, Kwave::MultiTrackReader &src,
-	            QIODevice &dst,
-	            const Kwave::MetaDataList &meta_data) Q_DECL_OVERRIDE;
+        virtual bool encode(QWidget *widget, Kwave::MultiTrackReader &src,
+	                    QIODevice &dst,
+	                    const Kwave::MetaDataList &meta_data)
+            Q_DECL_OVERRIDE;
 
 	/** Returns a list of supported file properties */
-	QList<Kwave::FileProperty> supportedProperties() Q_DECL_OVERRIDE;
+        virtual QList<Kwave::FileProperty> supportedProperties()
+            Q_DECL_OVERRIDE;
 
     private:
 
